# Environment
- Operating system and version
- Python version

# Pympress
- version
- Installation method: source, pip, or binary installer?

# Expected behaviour 
What are you trying to achieve? What's the expected outcome?

# Steps to reproduce
What are you doing? 

# Problem
What's happening instead of what you are expecting?
What is reported in pympress.log?

It is located in the temporary folder, thus one of the following locations:
> /tmp/pympress.log
> /var/tmp/pympress.log
> /usr/tmp/pympress.log
> C:\Users\<username>\AppData\Local\Temp\pympress.log
> C:\TEMP\pympress.log
> C:\TMP\pympress.log
